export let common = null;

runOnStartup(async runtime =>
{
	runtime.addEventListener("beforeprojectstart", async () => {
		const config = await runtime.assets.fetchJson("config.json");
		common = new Common(runtime, config);
	});
});

class Common
{
	constructor(runtime, config)
	{
		this.runtime = runtime;
		this.config = config;
		
		this.b_debug = config["console debug"];
		
		this.b_requestState = false;
		
		this.requestTag = "";
	}
	
	request(tag, data)
	{
		if (this.b_requestState) return;
		this.b_requestState = true;
		
		const config = this.config;
		
		const url = `${config["url"]}${config["ajax debug"] ? "debug" : "default"}/${tag}.php`;
		
		this.requestTag = tag;
		
		if (this.b_debug) console.log(url, tag, 'wait...');
		
		this.runtime.callFunction("_AJAX", url, data);
	}
	
	response(data)
	{
		if (this.b_debug) console.log(data);
		
		const response = JSON.parse(data);
		
		this._update_data(response["response"], "data" in response ? response["data"] : "");
		
		this.runtime.callFunction("_Response", this.requestTag);
		
		this.b_requestState = false;
	}
	
	_update_data(response, data)
	{
		const JSON_Data = this.runtime.objects.JSON_Data.getFirstInstance();
		const copy = JSON_Data.getJsonDataCopy();
		
		copy["response"] = response;
		
		if (data !== "")
		{
			if (!("data" in copy)) copy["data"] = {};
		
			for (const [key, value] of Object.entries(data))
			{
				copy["data"][key] = value;
			}
		}
		
		JSON_Data.setJsonDataCopy(copy);
	}
}